@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $superduper: xmms-mad.h,v 1.6 2004/05/27 11:03:47 sam Exp $
+ * $superduper: xmms-mad.h,v 1.7 2004/10/30 10:20:05 sam Exp $
  */
 #ifndef XMMS_MAD_H
 #define XMMS_MAD_H
@@ -64,6 +64,7 @@ struct mad_info_t
   gchar *url;
   gchar *filename;
   gint infile;
+  gint offset;
 
   gint remote;
   struct streamdata_t *sdata; /**< stream data for remote connections */
@@ -74,6 +75,7 @@ struct xmmsmad_config_t
   gint http_buffer_size;
   gboolean fast_play_time_calc;
   gboolean use_xing;
+  gboolean dither;
 };
 
 extern void *decode (void *arg);
